# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),

## [Unreleased]

## [0.2.1]
### Changed
- Default port when creating new `QuantumMachineManager` is now `80` and user 
config file is ignored

## [0.2.0]
### Added
- The original QM SDK for QOP 2

## [0.1.0]
### Added
- The original QM SDK for QOP 1

[Unreleased]: https://github.com/qm-labs/qm-qua-sdk/compare/v0.2.1...HEAD
[0.2.1]: https://github.com/qm-labs/qm-qua-sdk/compare/v0.2.0...v0.2.1
[0.2.0]: https://github.com/qm-labs/qm-qua-sdk/compare/v0.1.0...v0.2.0
[0.1.0]: https://github.com/qm-labs/qm-qua-sdk/releases/tag/v0.1.0